/***********************************************************************/
/*                                                                     */
/*   SVMTorch                                                          */
/*                                                                     */
/*   Author: Ronan Collobert                                           */
/*   Date: 21.07.2000                                                  */
/*                                                                     */
/*   Copyright (c) 2000  IDIAP - All rights reserved                   */
/*                                                                     */
/*   This software is available for non-commercial use only. It must   */
/*   not be modified and distributed without prior permission of the   */
/*   author. The author is not responsible for implications from the   */
/*   use of this software.                                             */
/*                                                                     */
/***********************************************************************/
  

#include "kernel.h"

void kernelInit(void)
{
	k_user = (char *)malloc(sizeof(char)*2);
	strcpy(k_user, "X");

	k_poly = 2;
	k_exp = 0.01;
	k_sigm_s = 1;
	k_sigm_c = 1;

	/* Default Kernel Type and Initialization */
	t_kernel = 2;
	kernel = kernel_exp;
}

real kernel_linear(real *x, real *y)
{
	int i;
	real sum;

	sum = 0;
	for(i = 0; i < width; i++)
		sum += *x++ * *y++;

	return(sum);
}

real kernel_exp(real *x, real *y)
{
	int i;
	real sum;
	real z;

	sum = 0;
	for(i = 0; i < width; i++)
	{
		z = *x++ - *y++;
		sum += z*z;
	}

	sum = exp(-sum*k_exp);

	return(sum);
}

real kernel_poly(real *x, real *y)
{
	int i, j;
	real sum;
	real z;

	sum = 0;
	for(i = 0; i < width; i++)
		sum += *x++ * *y++;

	sum *= k_sigm_s;
	sum += k_sigm_c;

	z = 1;
	for(j = 0; j < k_poly; j++)
		z *= sum;

	return(z);
}


real kernel_sigm(real *x, real *y)
{
	int i;
	real sum;

	sum = 0;
	for(i = 0; i < width; i++)
		sum += *x++ * *y++;

	sum *= k_sigm_s;
	sum += k_sigm_c;

	

	return(tanh(sum));
}

